Fusion Rings
============

.. toctree::
   :maxdepth: 2

   sage/algebras/fusion_rings/fusion_ring
   sage/algebras/fusion_rings/f_matrix
   sage/algebras/fusion_rings/fusion_double

F-Matrix Backend
----------------

.. toctree::
   :maxdepth: 2

   sage/algebras/fusion_rings/fast_parallel_fmats_methods
   sage/algebras/fusion_rings/fast_parallel_fusion_ring_braid_repn
   sage/algebras/fusion_rings/poly_tup_engine
   sage/algebras/fusion_rings/shm_managers

